package com.bonus.sgzb.material.mapper;

import com.bonus.sgzb.base.api.domain.MaInputRecord;
import com.bonus.sgzb.base.api.domain.MaMachine;
import com.bonus.sgzb.base.api.domain.MaType;
import com.bonus.sgzb.material.domain.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 新购验收任务purchase_check_infoMapper接口
 * 
 * @author bonus
 * @date 2023-12-10
 */
@Mapper
public interface PurchaseCheckServiceCenterMapper
{
    /**
     * 查询新购验收任务purchase_check_info
     * 
     * @param taskId 新购验收任务purchase_check_info主键
     * @return 新购验收任务purchase_check_info
     */
    public PurchaseCheckInfo selectPurchaseCheckInfoByTaskId(Long taskId);

    /**
     * 查询新购验收任务purchase_check_info列表
     * 
     * @param purchaseCheckInfo 新购验收任务purchase_check_info
     * @return 新购验收任务purchase_check_info集合
     */
    public List<PurchaseCheckInfo> selectPurchaseCheckInfoList(PurchaseCheckInfo purchaseCheckInfo);

    /**
     * 新增新购验收任务purchase_check_info
     * 
     * @param purchaseCheckInfo 新购验收任务purchase_check_info
     * @return 结果
     */
    public int insertPurchaseCheckInfo(PurchaseCheckInfo purchaseCheckInfo);

    /**
     * 修改新购验收任务purchase_check_info
     * 
     * @param purchaseCheckInfo 新购验收任务purchase_check_info
     * @return 结果
     */
    public int updatePurchaseCheckInfo(PurchaseCheckInfo purchaseCheckInfo);

    /**
     * 删除新购验收任务purchase_check_info
     * 
     * @param taskId 新购验收任务purchase_check_info主键
     * @return 结果
     */
    public int deletePurchaseCheckInfoByTaskId(Long taskId);

    /**
     * 批量删除新购验收任务purchase_check_info
     * 
     * @param taskIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePurchaseCheckInfoByTaskIds(Long[] taskIds);

    /**
     * 查询新购入库任务列表
     * @param taskId
     ** @param type 1-验收，2-入库
     * @return
     */
    String selectTypeNameByTaskId(@Param("taskId") Long taskId,@Param("type") String type);

    /**
     * 插入
     * @param bmNoticeInfo
     * @return
     */
    int insertBmNoticeInfo(BmNoticeInfo bmNoticeInfo);

    /**
     * 查询
     * @param purchaseCheckInfo
     * @return
     */
    List<PurchaseCheckInfo> selectPutInListList(PurchaseCheckInfo purchaseCheckInfo);

    /**
     * 新购验收
     * @param purchaseCheckInfo
     * @return
     */
    List<PurchaseCheckInfo> exportList(PurchaseCheckInfo purchaseCheckInfo);
    /**
     * 新购入库导出
     * @param purchaseCheckInfo
     * @return
     */
    List<PurchaseInput> putInExportList(PurchaseCheckInfo purchaseCheckInfo);

    /**
     * 获取入库清单明细
     * @param purchaseMacodeInfo
     * @return
     */
    List<PurchaseMacodeInfo> selectPutinDetails(PurchaseMacodeInfo purchaseMacodeInfo);

    /**
     * 修改
     * @param maMachine
     * @return
     */
    int updateMaMachine(MaMachine maMachine);

    /**
     * 查询
     * @param typeId
     * @return
     */
    MaType selectTypeByTypeId(Long typeId);

    /**
     * 修改
     * @param maType
     * @return
     */
    int updateTypeByTypeId(MaType maType);

    /**
     * 插入
     * @param applyDetails
     * @return
     */
    int insertInputApplyDetails(InputApplyDetails applyDetails);

    /**
     * 修改
     * @param purchaseMacodeInfo
     * @return
     */
    int updateMacodeByType(PurchaseMacodeInfo purchaseMacodeInfo);

    /**
     * 插入
     * @param maInputRecord
     * @return
     */
    int insertMaInputRecord(MaInputRecord maInputRecord);

    /**
     * 删除ma_machine表
     * @param maId
     * @return 结果
     */
    int deleteMaMachineInfoByMaId(Long maId);

    /**
     * 删除ma_machine_label表
     * @param maId
     * @return int
     */
    int deleteMaMachineLabelByMaId(Long maId);

    /**
     * 删除ma_label_bind表
     * @param maId
     * @return int
     */
    int deleteMaLabelBindByMaId(Long maId);

    /**
     * 删除purchase_macode_info表
     * @param taskId
     * @param typeId
     * @param maCode
     * @return
     */
    int updatetePurchaseMaCodeInfoByMaCodeAndTaskIdAndTypeId(@Param("taskId") Long taskId,@Param("typeId") Long typeId,@Param("maCode") String maCode);

    /**
     * 当全部为已入库的时候任务改为入库状态
     * @param taskId
     * @return
     */
    Integer selectMacodeInfoStatusByTaskId(Long taskId);

    /**
     * 查询组织是否开启审核
     * @param companyId
     * @return int
     */
    int selectExamineType(Long companyId);

    /**
     * 判断是否全部已操作（不通过或通过）
     * @param taskId
     * @return int
     */
    int isOperateAll(Long taskId);

    /**
     * 是否为全部不通过
     * @param taskId
     * @return
     */
    int selectPurchaseCheckDetailsStatus(Long taskId);
}
